@@ -1,6 +1,6 @@
 package Ubic::Admin::Setup;
 {
-  $Ubic::Admin::Setup::VERSION = '1.52';
+  $Ubic::Admin::Setup::VERSION = '1.53';
 }
 
 # ABSTRACT: this module handles ubic setup: asks user some questions and configures your system
@@ -383,23 +383,21 @@ sub setup {
             die "crontab -l failed";
         }
 
-        if ($old_crontab =~ /\subic-watchdog\b/) {
-            open my $fh, '|-', 'crontab -' or die "Can't run 'crontab -': $!";
-            my $printc = sub {
-                print {$fh} @_ or die "Can't write to pipe: $!";
-            };
-            my @crontab_lines = split /\n/, $old_crontab;
-            @crontab_lines = grep { $_ !~ /\Qubic-watchdog ubic.watchdog\E/ } @crontab_lines;
-            $printc->($old_crontab."\n");
+        my @crontab_lines = split /\n/, $old_crontab;
+        @crontab_lines = grep { $_ !~ /\Qubic-watchdog ubic.watchdog\E/ } @crontab_lines;
 
-            my $crontab_command = "$crontab_env_fix$ubic_watchdog_full_name ubic.watchdog";
-            if ($crontab_wrap_bash) {
-                $crontab_command = "bash -c '$crontab_command'";
-            }
-            push @crontab_lines, "* * * * * $crontab_command    >>$log_dir/watchdog.log 2>>$log_dir/watchdog.err.log";
-            $printc->("$_\n") for @crontab_lines;
-            close $fh or die "Can't close pipe: $!";
+        open my $fh, '|-', 'crontab -' or die "Can't run 'crontab -': $!";
+        my $printc = sub {
+            print {$fh} @_ or die "Can't write to pipe: $!";
+        };
+
+        my $crontab_command = "$crontab_env_fix$ubic_watchdog_full_name ubic.watchdog";
+        if ($crontab_wrap_bash) {
+            $crontab_command = "bash -c '$crontab_command'";
         }
+        push @crontab_lines, "* * * * * $crontab_command    >>$log_dir/watchdog.log 2>>$log_dir/watchdog.err.log";
+        $printc->("$_\n") for @crontab_lines;
+        close $fh or die "Can't close pipe: $!";
     }
 
     print "Installing $config_file...\n";
@@ -430,7 +428,7 @@ Ubic::Admin::Setup - this module handles ubic setup: asks user some questions an
 
 =head1 VERSION
 
-version 1.52
+version 1.53
 
 =head1 DESCRPITION
 
